@@ -30,6 +30,7 @@ from functools import partial
 
 from devsecops_engine_tools.engine_utilities.utils.logger_info import MyLogger
 from devsecops_engine_tools.engine_utilities import settings
+from devsecops_engine_tools.engine_utilities.defect_dojo.domain.serializers.import_scan import ImportScanSerializer
 import time
 import concurrent.futures
 
@@ -87,44 +88,17 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                 tags = vulnerability_management.dict_args["tool"]
                 if vulnerability_management.dict_args["tool"] == "engine_iac":
                     tags = f"{vulnerability_management.dict_args['tool']}_{'_'.join(vulnerability_management.dict_args['platform'])}"
-                request: ImportScanRequest = Connect.cmdb(
-                    cmdb_mapping={
-                        "product_type_name": "nombreevc",
-                        "product_name": "nombreapp",
-                        "tag_product": "nombreentorno",
-                        "product_description": "arearesponsableti",
-                        "codigo_app": "CodigoApp",
-                    },
-                    compact_remote_config_url=f'{vulnerability_management.base_compact_remote_config_url}{vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB_MAPPING_PATH"]}',
-                    personal_access_token=vulnerability_management.access_token,
-                    token_cmdb=token_cmdb,
-                    host_cmdb=vulnerability_management.config_tool[
-                        "VULNERABILITY_MANAGER"
-                    ]["DEFECT_DOJO"]["HOST_CMDB"],
-                    expression=vulnerability_management.config_tool[
-                        "VULNERABILITY_MANAGER"
-                    ]["DEFECT_DOJO"]["REGEX_EXPRESSION_CMDB"],
-                    token_defect_dojo=token_dd,
-                    host_defect_dojo=vulnerability_management.config_tool[
-                        "VULNERABILITY_MANAGER"
-                    ]["DEFECT_DOJO"]["HOST_DEFECT_DOJO"],
-                    scan_type=scan_type_mapping[vulnerability_management.scan_type],
-                    engagement_name=vulnerability_management.input_core.scope_pipeline,
-                    service=vulnerability_management.input_core.scope_pipeline,
-                    file=vulnerability_management.input_core.path_file_results,
-                    version=vulnerability_management.version,
-                    build_id=vulnerability_management.build_id,
-                    source_code_management_uri=vulnerability_management.source_code_management_uri,
-                    branch_tag=vulnerability_management.branch_tag,
-                    commit_hash=vulnerability_management.commit_hash,
-                    environment=(
-                        enviroment_mapping[vulnerability_management.environment.lower()]
-                        if vulnerability_management.environment is not None
-                        and vulnerability_management.environment.lower()
-                        in enviroment_mapping
-                        else enviroment_mapping["default"]
-                    ),
-                    tags=tags,
+
+                use_cmdb = vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB"]["USE_CMDB"]
+
+                request = self._build_request_importscan(
+                    vulnerability_management,
+                    token_cmdb,
+                    token_dd,
+                    scan_type_mapping,
+                    enviroment_mapping,
+                    tags,
+                    use_cmdb
                 )
 
                 def request_func():
@@ -170,7 +144,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                     request={
                         "name": Connect.get_code_app(
                             service,
-                            config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"][
+                            config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB"][
                                 "REGEX_EXPRESSION_CMDB"
                             ],
                         ),
@@ -387,6 +361,74 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
                     ex
                 )
             )
+        
+    def _build_request_importscan(
+        self,
+        vulnerability_management: VulnerabilityManagement,
+        token_cmdb,
+        token_dd,
+        scan_type_mapping,
+        enviroment_mapping,
+        tags,
+        use_cmdb: bool
+    ):
+        common_fields = {
+            "scan_type": scan_type_mapping[vulnerability_management.scan_type],
+            "file": vulnerability_management.input_core.path_file_results,
+            "engagement_name": vulnerability_management.input_core.scope_pipeline,
+            "source_code_management_uri": vulnerability_management.source_code_management_uri,
+            "tags": tags,
+            "version": vulnerability_management.version,
+            "build_id": vulnerability_management.build_id,
+            "branch_tag": vulnerability_management.branch_tag,
+            "commit_hash": vulnerability_management.commit_hash,
+            "service": vulnerability_management.input_core.scope_pipeline,
+            "environment": (
+                enviroment_mapping[vulnerability_management.environment.lower()]
+                if vulnerability_management.environment is not None
+                and vulnerability_management.environment.lower()
+                in enviroment_mapping
+                else enviroment_mapping["default"]
+            ),
+            "token_defect_dojo": token_dd,
+            "host_defect_dojo": vulnerability_management.config_tool[
+                "VULNERABILITY_MANAGER"
+            ]["DEFECT_DOJO"]["HOST_DEFECT_DOJO"],
+            "expression": vulnerability_management.config_tool[
+                "VULNERABILITY_MANAGER"
+            ]["DEFECT_DOJO"]["CMDB"]["REGEX_EXPRESSION_CMDB"],
+        }
+
+        if use_cmdb:
+            cmdb_mapping = vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB"]["CMDB_MAPPING"]
+            return Connect.cmdb(
+                cmdb_mapping={
+                    "product_type_name": cmdb_mapping["PRODUCT_TYPE_NAME"],
+                    "product_name": cmdb_mapping["PRODUCT_NAME"],
+                    "tag_product": cmdb_mapping["TAG_PRODUCT"],
+                    "product_description": cmdb_mapping["PRODUCT_DESCRIPTION"],
+                    "codigo_app": cmdb_mapping["CODIGO_APP"],
+                },
+                compact_remote_config_url=f'{vulnerability_management.base_compact_remote_config_url}{vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB"]["CMDB_MAPPING_PATH"]}',
+                personal_access_token=vulnerability_management.access_token,
+                token_cmdb=token_cmdb,
+                host_cmdb=vulnerability_management.config_tool[
+                    "VULNERABILITY_MANAGER"
+                ]["DEFECT_DOJO"]["CMDB"]["HOST_CMDB"],
+                cmdb_request_response=vulnerability_management.config_tool["VULNERABILITY_MANAGER"]["DEFECT_DOJO"]["CMDB"]["CMDB_REQUEST_RESPONSE"],
+                **common_fields,
+            )
+        else:
+            request: ImportScanRequest = ImportScanSerializer().load(
+                {
+                    "product_type_name":vulnerability_management.vm_product_type_name,
+                    "product_name": vulnerability_management.vm_product_name,
+                    "product_description":vulnerability_management.vm_product_description,
+                    "code_app":vulnerability_management.vm_product_name,
+                    **common_fields,
+                }
+            )
+            return request
 
     def _process_component(self, component_sbom, session_manager, engagement):
         request = {
@@ -493,9 +535,9 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
 
     def _create_exclusion(self, finding, date_fn, tool, reason):
         create_date, expired_date = self._date_reason_based(finding, date_fn, reason)
-
+            
         return Exclusions(
-            id=finding.vuln_id_from_tool,
+            id=finding.vuln_id_from_tool if finding.vuln_id_from_tool else finding.vulnerability_ids[0]["vulnerability_id"],
             where=self._get_where(finding, tool),
             create_date=create_date,
             expired_date=expired_date,
@@ -507,7 +549,7 @@ class DefectDojoPlatform(VulnerabilityManagementGateway):
         create_date, expired_date = self._date_reason_based(finding, date_fn, reason)
 
         return Exclusions(
-            id=finding.vuln_id_from_tool,
+            id=finding.vuln_id_from_tool if finding.vuln_id_from_tool else finding.id[0]["vulnerability_id"],
             where=self._get_where(finding, tool),
             create_date=create_date,
             expired_date=expired_date,
