@@ -30,6 +30,9 @@ class PrismaDeserealizator(DeseralizatorGateway):
             image_object = file.read()
 
             json_data = json.loads(image_object)
+            console_url = json_data.get("consoleURL",False)
+            if console_url:
+                print(f"Console URL: {console_url}")
             vulnerabilities_data = (
                 json_data["results"][0]["vulnerabilities"]
                 if "vulnerabilities" in json_data["results"][0]
