@@ -4,5 +4,5 @@ from devsecops_engine_tools.engine_core.src.domain.model.finding import Finding
 
 class DeserializatorGateway(metaclass=ABCMeta):
     @abstractmethod
-    def get_list_findings(self, results_scan_file) -> "list[Finding]":
+    def get_list_findings(self, results_scan_file, remote_config) -> "list[Finding]":
         "Deserializator"
